/usr/bin/touch /var/lib/texmf/postinstall/texlive-collection-mathscience_rm.lsr
/usr/bin/updmap-sys --nohash --nomkmap \
--disable chemarrow.map \
--disable stmaryrd.map \
--disable yhmath.map \

/usr/bin/fmtutil-sys --disablefmt amstex/pdftex
/usr/bin/fmtutil-sys --disablefmt amstex/pdftex
/usr/libexec/update_tlpdb remove \
12many \
accents \
alg \
algobox \
algorithm2e \
algorithmicx \
algorithms \
algpseudocodex \
algxpar \
aligned-overset \
amscdx \
amstex \
amstex.x86_64-cygwin \
annotate-equations \
apxproof \
autobreak \
axodraw2 \
backnaur \
begriff \
binomexp \
biocon \
bitpattern \
bodeplot \
bohr \
boldtensors \
bosisio \
bpchem \
bropd \
bussproofs-extra \
bussproofs \
bytefield \
calculation \
cartonaugh \
cascade \
causets \
ccfonts \
ccool \
chemarrow \
chemcompounds \
chemcono \
chemexec \
chemformula \
chemgreek \
chemmacros \
chemnum \
chemobabel \
chemplants \
chemschemex \
chemsec \
chemstyle \
clrscode \
clrscode3e \
codeanatomy \
collection-mathscience \
commath \
commutative-diagrams \
complexity \
computational-complexity \
concmath \
concrete \
conteq \
correctmathalign \
cryptocode \
csassignments \
cvss \
decision-table \
delim \
delimseasy \
delimset \
derivative \
diffcoeff \
digiconfigs \
dijkstra \
drawmatrix \
drawstack \
dyntree \
easing \
ebproof \
econometrics \
eltex \
emf \
endiagram \
engtlc \
eolang \
eqexpl \
eqnarray \
eqnnumwarn \
euclideangeometry \
extarrows \
extpfeil \
faktor \
fascicules \
fixdif \
fixmath \
fnspe \
formal-grammar \
fouridx \
functan \
galois \
gastex \
gene-logic \
ghsystem \
glosmathtools \
gotoh \
grundgesetze \
gu \
helmholtz-ellis-ji-notation \
hep-reference \
hep \
hepnames \
hepparticles \
hepthesis \
hepunits \
ibrackets \
includernw \
interval \
ionumbers \
isomath \
jkmath \
jupynotex \
karnaugh-map \
karnaugh \
karnaughmap \
kvmap \
letterswitharrows \
lie-hasse \
logicproof \
longdivision \
lpform \
lplfitch \
lstbayes \
mathcommand \
mathcomp \
mathfixs \
mathlig \
mathpartir \
mathpunctspace \
mathsemantics \
matlab-prettifier \
matrix-skeleton \
mattens \
mecaso \
membranecomputing \
memorygraphs \
messagepassing \
mgltex \
mhchem \
mhequ \
miller \
mismath \
multiobjective \
naive-ebnf \
namedtensor \
natded \
nath \
nchairx \
nicematrix \
nuc \
nucleardata \
numerica-plus \
numerica-tables \
numerica \
objectz \
oplotsymbl \
ot-tableau \
oubraces \
overarrows \
pascaltriangle \
perfectcut \
pfdicons \
physconst \
physics \
physics2 \
physunits \
pinoutikz \
pm-isomath \
polexpr \
prftree \
principia \
proba \
proof-at-the-end \
prooftrees \
pseudo \
pseudocode \
pythonhighlight \
qsharp \
rank-2-roots \
rbt-mathnotes \
rec-thy \
resolsysteme \
rest-api \
revquantum \
ribbonproofs \
rmathbr \
sankey \
sasnrdisplay \
sciposter \
sclang-prettifier \
scratchx \
sesamanuel \
sfg \
shuffle \
simplebnf \
simpler-wick \
simples-matrices \
simplewick \
sistyle \
siunits \
siunitx \
skmath \
spalign \
spbmark \
stanli \
statex \
statex2 \
statistics \
statistik \
statmath \
steinmetz \
stmaryrd \
structmech \
struktex \
substances \
subsupscripts \
subtext \
susy \
syllogism \
sympytexpackage \
synproof \
t-angles \
tablor \
tensind \
tensor \
tex-ewd \
textgreek \
textopo \
thermodynamics \
thmbox \
tiscreen \
turnstile \
ulqda \
ulqda.x86_64-cygwin \
unitsdef \
venn \
witharrows \
xymtex \
yhmath \
youngtab \
yquant \
ytableau \
zx-calculus \

